@@ -14,14 +14,13 @@
 #    under the License.
 
 import re
-
-from oslo_log import log as logging
-from oslo_utils import strutils
 import webob.exc
 import wsgi
 
 from trove.common import exception
-from trove.common.i18n import _
+from trove.openstack.common import log as logging
+from trove.openstack.common.gettextutils import _
+from trove.openstack.common import strutils
 
 LOG = logging.getLogger(__name__)
 
@@ -30,22 +29,22 @@ class AuthorizationMiddleware(wsgi.Middleware):
 
     def __init__(self, application, auth_providers, **local_config):
         self.auth_providers = auth_providers
-        LOG.debug("Auth middleware providers: %s" % auth_providers)
+        LOG.debug(_("Auth middleware providers: %s") % auth_providers)
         super(AuthorizationMiddleware, self).__init__(application,
                                                       **local_config)
 
     def process_request(self, request):
         roles = request.headers.get('X_ROLE', '').split(',')
-        LOG.debug("Processing auth request with roles: %s" % roles)
+        LOG.debug(_("Processing auth request with roles: %s") % roles)
         tenant_id = request.headers.get('X-Tenant-Id', None)
-        LOG.debug("Processing auth request with tenant_id: %s" % tenant_id)
+        LOG.debug(_("Processing auth request with tenant_id: %s") % tenant_id)
         for provider in self.auth_providers:
             provider.authorize(request, tenant_id, roles)
 
     @classmethod
     def factory(cls, global_config, **local_config):
         def _factory(app):
-            LOG.debug("Created auth middleware with config: %s" %
+            LOG.debug(_("Created auth middleware with config: %s") %
                       local_config)
             return cls(app, [TenantBasedAuth()], **local_config)
         return _factory
@@ -66,11 +65,8 @@ class TenantBasedAuth(object):
                         "%(request)s") %
                       {'tenant_id': tenant_id, 'request': request}))
             return True
-
-        msg = _(
-            "User with tenant id %s cannot access this resource.") % tenant_id
-
-        LOG.error(msg)
+        msg = _("User with tenant id %s cannot access this resource")
+        LOG.debug(msg % tenant_id)
         raise webob.exc.HTTPForbidden(msg)
 
 
