@@ -14,19 +14,18 @@
 #    under the License.
 
 
-from oslo_log import log as logging
-
-from trove.common.auth import admin_context
-from trove.common.i18n import _
 from trove.common import wsgi
+from trove.common.auth import admin_context
 from trove.extensions.mgmt.volume import models
 from trove.extensions.mgmt.volume import views
+from trove.openstack.common import log as logging
+from trove.openstack.common.gettextutils import _
 
 LOG = logging.getLogger(__name__)
 
 
 class StorageController(wsgi.Controller):
-    """Controller for storage device functionality."""
+    """Controller for storage device functionality"""
 
     @admin_context
     def index(self, req, tenant_id):
